@@ -1,50 +1,41 @@
-from environs import ParseResult
-from typing import Callable, List
+
 from enum import Enum
+from typing import Callable, List
 import os
 import functools
 import logging
 import json
 
-import requests
+import strconv
 import fitin
-import click
 
 from toolz.functoolz import compose,curry
 
-from . import exceptions, schema
+class IRemotePaths(Enum):
+    querysets = 1
+    documentation = 2
 
 logger = logging.getLogger(__name__)
 
-def try_to_reach(url):
-    try:
-        rsp = requests.get(url)
-        assert str(rsp.status_code)[0] == "2"
-    except (
-            requests.exceptions.MissingSchema,
-            requests.exceptions.ConnectionError,
-            requests.exceptions.ConnectTimeout,
-            AssertionError
-            ):
-        raise exceptions.ConfigurationError(
-                f"Could not reach url \"{url}\". Please enter a valid "
-                "remote url."
-            )
-    return url
-
 REQUIRED_SETTINGS = (
-            ("REMOTE_URL", try_to_reach),
+            "REMOTE_URL",
         )
 
 DEFAULT_SETTINGS = {
-        "RETRY_FREQUENCY": 5, # seconds
-        "RETRIES": 80,
-        "LOG_LEVEL": "INFO",
-        "HANDSHAKE_PATH": "",
-        "REPO_URL": "https://www.github.com/prio-data/viewser",
-        "LATEST_KNOWN_VERSION": "0.0.0",
+        "RETRY_FREQUENCY":                  5, # seconds
+        "RETRIES":                          80,
+        "LOG_LEVEL":                        "INFO",
+        "HANDSHAKE_PATH":                   "",
+        "REPO_URL":                         "https://www.github.com/prio-data/viewser",
+        "LATEST_KNOWN_VERSION":             "0.0.0",
         "NOTEBOOK_SERVER_IMAGE_REPOSITORY": "prio-data/viewserspace",
-        "NOTEBOOK_SERVER_IMAGE_REGISTRY": "viewsregistry.azurecr.io"
+        "NOTEBOOK_SERVER_IMAGE_REGISTRY":   "viewsregistry.azurecr.io",
+        "ERROR_DUMP_DIRECTORY":             "dumps",
+        "MODEL_OBJECT_SFTP_USER":           "predictions",
+        "MODEL_OBJECT_SFTP_PORT":           22222,
+        "MODEL_OBJECT_SFTP_HOSTNAME":       "hermes",
+        "MODEL_OBJECT_KEY_DB_HOSTNAME":     "janus",
+        "MODEL_OBJECT_KEY_DB_DBNAME":       "pred3_certs",
     }
 
 CONFIG_DIR = os.path.expanduser("~/.views")
@@ -137,7 +128,7 @@ def copy_to_config_file(fn):
         return val
     return inner
 
-def seek_config(sources: List[Callable[[str],str]], default: Callable[[str],str])-> str:
+def seek_config(sources: List[Callable[[str],str]], default: Callable[[str],str])-> Callable[[str],str]:
     def seeker(key):
         for source in sources:
 
@@ -148,11 +139,16 @@ def seek_config(sources: List[Callable[[str],str]], default: Callable[[str],str]
         return default()
     return seeker
 
-config_get = seek_config([
+config_sources = [
     fitin.environs_resolver(),
     fitin.dict_resolver(config_dict),
     copy_to_config_file(fitin.dict_resolver(DEFAULT_SETTINGS)),
-    ], str)
+    ]
+
+config_get = compose(
+        strconv.convert,
+        seek_config(config_sources,str)
+        )
 
 def is_config(key):
     try:
@@ -168,18 +164,20 @@ except(AttributeError, KeyError):
     logging.basicConfig(level=logging.INFO)
 
 def configure_interactively():
-    for key,validate in REQUIRED_SETTINGS:
+    for setting in REQUIRED_SETTINGS:
         value = None
         while not value:
-            try:
-                value = validate(input(f"{key} >> "))
-            except exceptions.ConfigurationError as cfge:
-                click.echo(str(cfge.message))
+            value = input(f"{setting} >> ")
         config_set_in_file(
-                key,
+                setting, value
             )
 
 REMOTE_PATHS = {
-        schema.IRemotePaths.querysets: "querysets",
-        schema.IRemotePaths.documentation: "docs",
+        IRemotePaths.querysets: "querysets",
+        IRemotePaths.documentation: "docs",
     }
+
+ERROR_DUMP_DIRECTORY = os.path.join(CONFIG_DIR, config_get("ERROR_DUMP_DIRECTORY"))
+
+QUERYSET_URL = os.path.join(config_get("REMOTE_URL"), "querysets")
+REMOTE_URL = config_get("REMOTE_URL")
